@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-import datetime, pytz
+import datetime, pytz,json,calendar,hashlib
 from django.utils import timezone
 from django.db import models
 from django.contrib.auth.models import User, Group
@@ -9,11 +9,17 @@ from django.dispatch import receiver
 from django.db.models.signals import post_save
 from django.apps import apps
 from django.conf import settings
+from dss.Serializer import serializer
+from imagekit.models import ProcessedImageField
+from imagekit.processors import ResizeToFill
+from django.utils.timezone import localtime
+
+
+
 from bee_django_crm.models import PreUser
 from .signals import update_user_expire_signal, create_user_signal
 
-from imagekit.models import ProcessedImageField
-from imagekit.processors import ResizeToFill
+
 
 LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')
 
@@ -32,7 +38,8 @@ class UserProfile(models.Model):
     user = models.OneToOneField(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, null=True)
     student_id = models.IntegerField(verbose_name='学号', unique=True, null=True)  # 拼接成用户名
     sn = models.IntegerField(verbose_name='统一缦客号', unique=True, null=True, help_text='只需填写数字')  # 各项目统一使用
-    room_id = models.CharField(max_length=180, verbose_name='习琴室ID', null=True, blank=True)
+    room_id = models.CharField(max_length=180, verbose_name='习琴室ID', null=True, blank=True)#cc
+    gensee_room_id = models.CharField(max_length=180, verbose_name='直播间ID', null=True, blank=True)#gensee
     user_class = models.ForeignKey('bee_django_user.UserClass', verbose_name='用户班级', on_delete=models.SET_NULL,
                                    null=True, blank=True)
     start_date = models.DateTimeField(null=True, blank=True, verbose_name='开课日期')
@@ -41,11 +48,13 @@ class UserProfile(models.Model):
     created_at = models.DateTimeField(auto_now_add=True)
     avatar = ProcessedImageField(null=True, blank=True, verbose_name='头像', upload_to='avatars',
                                  processors=[ResizeToFill(50, 50)],
-                                 format='JPEG',
-                                 default='avatars/default.jpg')
+                                 format='JPEG')
     is_pause = models.BooleanField(default=False, blank=True, verbose_name='暂停')
-    wxapp_openid = models.CharField(max_length=180, verbose_name='微信小程序open id', blank=True, null=True)
+    wxapp_openid = models.CharField(max_length=180, verbose_name='微信小程序open id', blank=True, null=True) #微信小程序
+    wxservice_openid = models.CharField(max_length=180, null=True, blank=True) #微信服务号
     parents = models.ManyToManyField(to='UserProfile', through='UserProfileParentRelation')
+    agent = models.ForeignKey("bee_django_user.UserProfile",related_name='agent_user',null=True, on_delete=models.SET_NULL,
+                               blank=True)#客服
 
     class Meta:
         db_table = 'bee_django_user_profile'
@@ -64,8 +73,33 @@ class UserProfile(models.Model):
             ('view_child_users', '可以查看亲子用户'),
         )
 
-    def __str__(self):
-        return self.user.username
+    def __unicode__(self):
+        return self.user.first_name
+
+
+    def to_json(self):
+        result = serializer(data=self, output_type='json', datetime_format='string',include_attr=('user_id',"student_id","sn","room_id","user_class","start_date","expire_date","preuser","avatar","is_pause"))
+        result_dict = json.loads(result)
+        result_dict["username"]=self.user.username
+        result_dict["name"]=self.user.first_name
+        result_dict["days"]=self.get_expire_days()
+        result_dict["is_unlimited"]=self.user.is_unlimited()
+        result_dict["get_sn"]=self.get_sn()
+        result_dict["coin"]=self.user.get_coin_count()
+        # 腾讯推流链接
+        # https://cloud.tencent.com/document/product/267/32735
+        if "tencent" in  settings.COURSE_LIVE_PROVIDER_LIST:
+            _datetime = timezone.now() + datetime.timedelta(days=3)
+            timestamp=calendar.timegm(_datetime.utctimetuple())
+            txTime=hex(timestamp)[2:]
+            m = hashlib.md5()
+            m.update(settings.COURSE_LIVE_TENCENT_KEY+self.user.username+txTime)
+            txSecret=m.hexdigest()
+            # print(txSecret)
+            result_dict["live_push_stream_param"]="txSecret="+txSecret+"&txTime="+txTime
+        else:
+            result_dict["live_push_stream_param"]=""
+        return json.dumps(result_dict)
 
     def has_group(self, group_name):
         group_name_list = []
@@ -129,6 +163,63 @@ class UserProfile(models.Model):
             max_sn = 0
         return max_sn
 
+
+    # 获取结课倒计时天数
+    def get_expire_days(self):
+        expire_date = self.expire_date
+        if expire_date:
+            now = timezone.now()
+            days = (expire_date - now).days
+        else:
+            days = None
+        return days
+
+
+    def get_expire_date_str(self,timezone=False):
+        if self.expire_date:
+            expire_date = localtime(self.expire_date)
+            if timezone:
+                return expire_date.strftime("%Y-%m-%d %H:%M:%S%z")
+            else:
+                return expire_date.strftime("%Y-%m-%d %H:%M:%S")
+        else:
+            return ''
+
+    # 助教用户组
+    @classmethod
+    def get_assistant_groupname_list(cls):
+        return ['助教']
+
+    # 客服用户组
+    @classmethod
+    def get_agent_groupname_list(cls):
+        return ['客服']
+
+    # 家长助教用户组
+    @classmethod
+    def get_parent_groupname_list(cls):
+        return ['家长助教']
+
+    # 亲子学生用户组
+    @classmethod
+    def get_child_groupname_list(cls):
+        return ['亲子学生']
+
+    # 是否是助教
+    def is_assistant(self):
+        groups= self.user.groups.filter(name__in=UserProfile.get_assistant_groupname_list())
+        if groups.exists():
+            return True
+        return False
+
+    # 是否亲子学生
+    def is_child(self):
+        groups= self.user.groups.filter(name__in=UserProfile.get_child_groupname_list())
+        if groups.exists():
+            return True
+        return False
+
+
     # 创建User
     # type-1:创建普通用户
     # type-2:亲子用户，创建一组账号
@@ -137,11 +228,11 @@ class UserProfile(models.Model):
         # preuser_id = request.GET["preuser_id"]
         # preuser_fee_id = request.GET["preuser_fee_id"]
         if not op_user.has_perm('bee_django_user.add_userprofile'):
-            return None, 1, "没有权限"
+            return None,None, 1, "没有权限"
         try:
             user_profile = preuser.userprofile
             if user_profile:
-                return None, 0, "已添加过用户，审核成功"
+                return None,None, 0, "已添加过用户，审核成功"
         except:
             pass
 
@@ -159,7 +250,7 @@ class UserProfile(models.Model):
         max_sn = UserProfile.get_max_sn()
         sn = UserSN.get_next_sn(max_sn)
         if not sn:
-            return None, 4, '统一缦客号生成错误'
+            return None,None, 4, '统一缦客号生成错误'
         user_profile.sn = sn
 
         # 学号
@@ -205,7 +296,7 @@ class UserProfile(models.Model):
             # 家长角色
             try:
                 p_group = Group.objects.get(name='家长助教')
-                p_user.groups.add(p_group)
+                # p_user.groups.add(p_group)
             except:
                 p_group = Group(name='家长助教')
                 p_group.save()
@@ -262,8 +353,16 @@ class UserSN(models.Model):
         elif i.start < new_sn < i.end:
             pass
         elif new_sn == i.end:
+            # 开启下一区间
+            next_list = cls.objects.filter(is_used=False).order_by('start')
+            if next_list.exists():
+                next = next_list.first()
+                next.is_used=True
+                next.save()
+            # 关闭当前区间
             i.is_used = False
             i.save()
+
         else:
             return None
         return new_sn
@@ -490,12 +589,8 @@ def get_user_name(self):
 
 # 学生列表页根据student_id搜索
 def get_user_search_link(self):
-    ex_link = "/user/list/?student_id="
-    search = self.userprofile.student_id
-    if not self.userprofile.student_id:
-        search = ''
-    else:
-        search = search.__str__()
+    ex_link = "/user/list/?id="
+    search = self.id.__str__()
     return ex_link + search
 
 
@@ -526,7 +621,6 @@ User.add_to_class("get_user_search_link", get_user_search_link)
 User.add_to_class("get_coin_count", get_coin_count)
 User.add_to_class("add_coin_record", add_coin_record)
 
-
 # 获取学生是否暂停
 def get_is_pause(self):
     if self.userprofile:
@@ -560,6 +654,8 @@ def get_user_profile_image(self):
             return None
     else:
         return None
+
+
 User.add_to_class('get_user_profile_image', get_user_profile_image)
 
 
@@ -569,9 +665,12 @@ def is_unlimited(self):
         if int(self.userprofile.expire_date.strftime("%Y")) >= 2999:
             return True
     return False
+
+
 User.add_to_class('is_unlimited', is_unlimited)
 
 
+
 # 获取亲子学生
 def get_child_users(self):
     return User.objects.filter(userprofile__parents=self.userprofile)
