@@ -24,7 +24,7 @@ from django.contrib.auth.forms import AdminPasswordChangeForm
 
 from .decorators import cls_decorator, func_decorator
 from .models import UserProfile, UserSN, UserProfileParentRelation, UserClass, UserLeaveRecord, LOCAL_TIMEZONE
-from .forms import UserForm, UserProfileParentsForm, UserSearchForm, profile_inline_formset, UserClassForm, \
+from .forms import UserForm, UserProfileParentsForm,UserAvatarForm, UserSearchForm, profile_inline_formset, UserClassForm, \
     UserClassSearchForm, UserGroupForm, \
     UserSNForm, \
     UserLeaveRecordForm, \
@@ -36,6 +36,21 @@ User = get_user_model()
 
 # Create your views here.
 def test(request):
+    u_l=UserProfile.objects.all()
+    for u in u_l:
+        u.avatar=None
+        u.save()
+    # print(u)
+    # a=u.userprofile.is_assistant()
+    # print(a)
+    # if hasattr(settings,"GENSEE_CONFIG"):
+    # print(b)
+    #     print(settings.GENSEE_CONFIG.genseeUrl)
+    # try:
+    #     a=settings.aaa
+    #     print('====')
+    # except:
+    #     print('222')
     return HttpResponse("OK")
 
 
@@ -66,12 +81,15 @@ class UserList(ListView):
             else:
                 filter2 = Q(pk=None)
             queryset=User.objects.filter(filter1|filter2).order_by('id').distinct()
+        id = self.request.GET.get("id")
         status = self.request.GET.get("status")
         student_id = self.request.GET.get("student_id")
         first_name = self.request.GET.get("first_name")
         group_id = self.request.GET.get("group")
         start_expire_date = self.request.GET.get("start_expire_date")
         end_expire_date = self.request.GET.get("end_expire_date")
+        if not id in [0,"0",None]:
+            queryset = queryset.filter(pk=id)
         if not status in [0, "0", None]:
             if status == "1":
                 queryset = queryset.filter(is_active=True, userprofile__is_pause=False).exclude(
@@ -312,6 +330,14 @@ class UserUpdate(UpdateView):
         context["formset"] = profile_inline_formset(instance=self.object)
         return context
 
+    def get_form_kwargs(self):
+        kwargs = super(UserUpdate, self).get_form_kwargs()
+        user=User.objects.get(id=self.kwargs["pk"])
+        kwargs.update({
+            'is_assistant': user.userprofile.is_assistant()
+        })
+        return kwargs
+
     @transaction.atomic
     def form_valid(self, form):
         if not self.request.user.has_perm('bee_django_user.change_userprofile'):
@@ -319,9 +345,19 @@ class UserUpdate(UpdateView):
             return redirect(reverse('bee_django_user:user_update', kwargs=self.kwargs))
         formset = profile_inline_formset(self.request.POST, self.request.FILES, instance=self.object)
         if formset.is_valid():
-            profile = formset.cleaned_data[0]
-            # room_id = profile['room_id']
-            # self.object.userprofile.room_id = room_id
+            # profile = formset.cleaned_data[0]
+            try:
+                agent=form.cleaned_data['agent']
+                # form.instance.agent = agent
+                self.object.userprofile.agent = agent
+            except KeyError:
+                pass
+
+            # profile.agent=agent
+            # print(agent)
+            # agent = profile['agent']
+            # print(agent)
+
             self.object.userprofile.save()
             messages.success(self.request, '修改成功')
         return super(UserUpdate, self).form_valid(form)
@@ -459,6 +495,18 @@ class StatusSave(TemplateView):
         })
 
 
+class AvatarUpdate(UpdateView):
+    model = UserProfile
+    form_class = UserAvatarForm
+    template_name = 'bee_django_user/user/avatar_form.html'
+
+    def get_success_url(self):
+        return reverse_lazy('bee_django_user:user_detail', kwargs=self.kwargs)
+
+    @transaction.atomic
+    def form_valid(self, form):
+        return super(AvatarUpdate, self).form_valid(form)
+
 # 请假记录
 class LeaveList(ListView):
     model = UserLeaveRecord
