@@ -8,6 +8,7 @@ from . import wxapp
 
 
 urlpatterns = [
-    url(r'^login/$', wxapp.login),
+    url(r'^login$', wxapp.login),
     url(r'^user/bind$', wxapp.user_bind),
+    url(r'^user/unbind$', wxapp.user_unbind),
 ]
